==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/outputs/AzureIaaSVMProtectedItemExtendedInfoResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.outputs

import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress

/**
 * Additional information on Azure IaaS VM specific backup item.
 * @property newestRecoveryPointInArchive The latest backup copy available for this backup item in archive tier
 * @property oldestRecoveryPoint The oldest backup copy available for this backup item across all tiers.
 * @property oldestRecoveryPointInArchive The oldest backup copy available for this backup item in archive tier
 * @property oldestRecoveryPointInVault The oldest backup copy available for this backup item in vault tier
 * @property policyInconsistent Specifies if backup policy associated with the backup item is inconsistent.
 * @property recoveryPointCount Number of backup copies available for this backup item.
 */
public data class AzureIaaSVMProtectedItemExtendedInfoResponse(
    public val newestRecoveryPointInArchive: String? = null,
    public val oldestRecoveryPoint: String? = null,
    public val oldestRecoveryPointInArchive: String? = null,
    public val oldestRecoveryPointInVault: String? = null,
    public val policyInconsistent: Boolean? = null,
    public val recoveryPointCount: Int? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.recoveryservices.outputs.AzureIaaSVMProtectedItemExtendedInfoResponse):
            AzureIaaSVMProtectedItemExtendedInfoResponse = AzureIaaSVMProtectedItemExtendedInfoResponse(
            newestRecoveryPointInArchive = javaType.newestRecoveryPointInArchive().map({ args0 ->
                args0
            }).orElse(null),
            oldestRecoveryPoint = javaType.oldestRecoveryPoint().map({ args0 -> args0 }).orElse(null),
            oldestRecoveryPointInArchive = javaType.oldestRecoveryPointInArchive().map({ args0 ->
                args0
            }).orElse(null),
            oldestRecoveryPointInVault = javaType.oldestRecoveryPointInVault().map({ args0 ->
                args0
            }).orElse(null),
            policyInconsistent = javaType.policyInconsistent().map({ args0 -> args0 }).orElse(null),
            recoveryPointCount = javaType.recoveryPointCount().map({ args0 -> args0 }).orElse(null),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/outputs/AzureIaaSVMProtectedItemExtendedInfoResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.outputs

import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress

/**
 * Additional information on Azure IaaS VM specific backup item.
 * @property newestRecoveryPointInArchive The latest backup copy available for this backup item in archive tier
 * @property oldestRecoveryPoint The oldest backup copy available for this backup item across all tiers.
 * @property oldestRecoveryPointInArchive The oldest backup copy available for this backup item in archive tier
 * @property oldestRecoveryPointInVault The oldest backup copy available for this backup item in vault tier
 * @property policyInconsistent Specifies if backup policy associated with the backup item is inconsistent.
 * @property recoveryPointCount Number of backup copies available for this backup item.
 */
public data class AzureIaaSVMProtectedItemExtendedInfoResponse(
    public val newestRecoveryPointInArchive: String? = null,
    public val oldestRecoveryPoint: String? = null,
    public val oldestRecoveryPointInArchive: String? = null,
    public val oldestRecoveryPointInVault: String? = null,
    public val policyInconsistent: Boolean? = null,
    public val recoveryPointCount: Int? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.recoveryservices.outputs.AzureIaaSVMProtectedItemExtendedInfoResponse): AzureIaaSVMProtectedItemExtendedInfoResponse = AzureIaaSVMProtectedItemExtendedInfoResponse(
            newestRecoveryPointInArchive = javaType.newestRecoveryPointInArchive().map({ args0 ->
                args0
            }).orElse(null),
            oldestRecoveryPoint = javaType.oldestRecoveryPoint().map({ args0 -> args0 }).orElse(null),
            oldestRecoveryPointInArchive = javaType.oldestRecoveryPointInArchive().map({ args0 ->
                args0
            }).orElse(null),
            oldestRecoveryPointInVault = javaType.oldestRecoveryPointInVault().map({ args0 ->
                args0
            }).orElse(null),
            policyInconsistent = javaType.policyInconsistent().map({ args0 -> args0 }).orElse(null),
            recoveryPointCount = javaType.recoveryPointCount().map({ args0 -> args0 }).orElse(null),
        )
    }
}
